@@ -24,7 +24,7 @@ import sys
 if sys.version_info < (2, 3):
     sys.exit("error: Python 2.3 or later required")
 
-from smart import init, initDistro, initPlugins, initPsyco
+from smart import init, initDistro, initPlugins, initPycurl, initPsyco
 from smart.const import VERSION, DATADIR
 from smart.option import OptionParser
 from smart import *
@@ -51,6 +51,7 @@ Action commands:
 Query commands:
     search
     query
+    newer
     info
     stats
 
@@ -91,6 +92,8 @@ def parse_options(argv):
                       help=_("use the default graphic interface"))
     parser.add_option("--shell", action="store_true",
                       help=_("use the default shell interface"))
+    parser.add_option("--quiet", action="store_true",
+                      help=_("use the quiet interface"))
     parser.add_option("--interface", metavar=_("NAME"),
                       help=_("use the given interface"))
     parser.add_option("--ignore-locks", action="store_true",
@@ -158,12 +161,14 @@ def main(argv):
         opts = parse_options(argv)
         ctrl = init(command=opts.command, argv=opts.argv,
                     datadir=opts.data_dir, configfile=opts.config_file,
-                    gui=opts.gui, shell=opts.shell, interface=opts.interface,
-                    forcelocks=opts.ignore_locks, loglevel=opts.log_level)
+                    gui=opts.gui, shell=opts.shell, quiet=opts.quiet,
+                    interface=opts.interface, forcelocks=opts.ignore_locks,
+                    loglevel=opts.log_level)
         if opts.option:
             set_config_options(opts.option)
         initDistro(ctrl)
         initPlugins()
+        initPycurl()
         initPsyco()
         exitcode = iface.run(opts.command, opts.argv)
         if exitcode is None:
