@@ -51,12 +51,13 @@ try:
     if not os.path.isdir(localedir):
         localedir = None
     _ = translation("smart", localedir).ugettext
+    encoding = locale.getpreferredencoding()
 except IOError, e:
     _ = lambda s: unicode(s)
-else:
+    encoding = sys.stdout.encoding or "ascii"
+if encoding:
     import codecs
     try:
-        encoding = locale.getpreferredencoding()
         sys.stdout = codecs.getwriter(encoding)(sys.stdout, errors="replace")
         sys.stderr = codecs.getwriter(encoding)(sys.stderr, errors="replace")
         del encoding
@@ -94,7 +95,7 @@ _smart_run_lock = thread.allocate_lock()
 
 def init(command=None, argv=None,
          datadir=None, configfile=None,
-         gui=False, shell=False, interface=None,
+         gui=False, shell=False, quiet=False, interface=None,
          forcelocks=False, loglevel=None):
     from smart.const import DEBUG, INFO, WARNING, ERROR
     from smart.const import DATADIR, USERDATADIR
@@ -127,6 +128,8 @@ def init(command=None, argv=None,
         ifacename = sysconf.get("default-shell", "text")
         if command:
             raise Error, _("Can't use commands with shell interfaces")
+    elif quiet:
+        ifacename = None
     elif interface:
         ifacename = interface
     else:
@@ -201,6 +204,11 @@ def initPlugins():
             if os.path.isfile(initpath):
                 __import__("smart.backends."+entry)
 
+def initPycurl():
+    if sysconf.get("pycurl", True):
+        # importing pycurl here segfaults
+        hooks.call("enable-pycurl")
+
 def initPsyco():
     if sysconf.get("psyco", True):
         try:
