@@ -19,3 +19,11 @@
 # along with Smart Package Manager; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+from smart import *
+import os
+
+def checkPackageFile(filename):
+    return os.path.isfile(filename) and filename.endswith(".deb")
+
+hooks.register("check-package-file", checkPackageFile)
+
