@@ -51,10 +51,13 @@ def getTS(new=False):
     rpm_root = os.path.abspath(sysconf.get("rpm-root", "/"))
     if not hasattr(getTS, "ts") or getTS.root != rpm_root:
         getTS.root = rpm_root
+        if sysconf.get("rpm-dbpath"):
+            rpm.addMacro('_dbpath', "/" + sysconf.get("rpm-dbpath"))
         getTS.ts = rpm.ts(getTS.root)
         if not sysconf.get("rpm-check-signatures", False):
             getTS.ts.setVSFlags(rpm._RPMVSF_NOSIGNATURES)
-        dbdir = os.path.join(getTS.root, "var/lib/rpm")
+        rpm_dbpath = sysconf.get("rpm-dbpath", "var/lib/rpm")
+        dbdir = os.path.join(getTS.root, rpm_dbpath)
         if not os.path.isdir(dbdir):
             try:
                 os.makedirs(dbdir)
@@ -77,6 +80,8 @@ def getTS(new=False):
             except OSError:
                 pass
     if new:
+        if sysconf.get("rpm-dbpath"):
+            rpm.addMacro('_dbpath', "/" + sysconf.get("rpm-dbpath"))
         ts = rpm.ts(getTS.root)
         if not sysconf.get("rpm-check-signatures", False):
             ts.setVSFlags(rpm._RPMVSF_NOSIGNATURES)
@@ -138,7 +143,8 @@ class RPMPackage(Package):
             return False
         selfver, selfarch = splitarch(self.version)
         otherver, otherarch = splitarch(other.version)
-        if getArchColor(selfarch) != getArchColor(otherarch):
+        if (getArchColor(selfarch) != getArchColor(otherarch) and
+            not sysconf.get("rpm-strict-multilib")):
             return True
         if not pkgconf.testFlag("multi-version", self):
             return False
