@@ -126,6 +126,21 @@ class RPMHeaderPackageInfo(PackageInfo):
                 break
         return result
 
+    def _getHeaderArray(self, tag):
+        result = self._h and self._h[tag] or []
+        if result:
+            if type(result) != list:
+                result = [result]
+            for i in range(len(result)):
+                if type(result[i]) == str:
+                    for encoding in ENCODINGS:
+                        try:
+                            result[i] = result[i].decode(encoding)
+                        except UnicodeDecodeError:
+                            continue
+                        break
+        return result
+
     def getDescription(self):
         return self._getHeaderString(rpm.RPMTAG_DESCRIPTION)
 
@@ -155,20 +170,14 @@ class RPMHeaderPackageInfo(PackageInfo):
 
     def getChangeLog(self):
         if self._change is None:
-            logname = self._h[rpm.RPMTAG_CHANGELOGNAME]
-            logtime = self._h[rpm.RPMTAG_CHANGELOGTIME]
-            change = self._h[rpm.RPMTAG_CHANGELOGTEXT]
-            if type(logname) != list:
-                logname = [logname]
-            if type(logtime) != list:
-                logtime = [logtime]              
-            if type(change) != list:
-                change = [change]
-            self._change = {}
+            logtime = self._getHeaderArray(rpm.RPMTAG_CHANGELOGTIME)
+            self._change = []
             if len(logtime) > 0:
+                logname = self._getHeaderArray(rpm.RPMTAG_CHANGELOGNAME)
+                change = self._getHeaderArray(rpm.RPMTAG_CHANGELOGTEXT)
                 for i in range(len(change)):
-                    self._change[2*i] = datetime.fromtimestamp(logtime[i]).strftime("%Y-%m-%d")+"  "+ logname[i]
-                    self._change[2*i+1] = "  " + change[i]
+                    self._change.append(datetime.fromtimestamp(logtime[i]).strftime("%Y-%m-%d")+"  "+ logname[i])
+                    self._change.append("  " + change[i])
         return self._change
 
     def getPathList(self):
@@ -561,12 +570,18 @@ class URPMILoader(RPMHeaderListLoader):
     def __init__(self, filename, baseurl, listfile):
         RPMHeaderListLoader.__init__(self, filename, baseurl)
         self._prefix = {}
-        if listfile:
-            for entry in open(listfile):
-                if entry[:2] == "./":
-                    entry = entry[2:]
-                dirname, basename = os.path.split(entry.rstrip())
-                self._prefix[basename] = dirname
+        self._flagdict = None
+
+    def setErrataFlags(self, flagdict):
+        self._flagdict = flagdict
+    
+    def buildPackage(self, pkgargs, prvargs, reqargs, upgargs, cnfargs):
+        pkg = Loader.buildPackage(self, pkgargs, prvargs, reqargs, upgargs, cnfargs)
+        name = pkgargs[1]
+        if hasattr(self, '_flagdict') and self._flagdict and name in self._flagdict:
+            if sysconf.getReadOnly():
+                pkgconf.setFlag(self._flagdict[name], name, "=", pkgargs[2])
+        return pkg
 
     def getFileName(self, info):
         h = info._h
@@ -608,14 +623,18 @@ class RPMDBLoader(RPMHeaderLoader):
             prog.show()
         prog.add(left)
 
-    if rpmhelper:
-        def getHeader(self, pkg):
+    def getHeader(self, pkg):
+        if rpmhelper:
             mi = rpmhelper.dbMatch(getTS(), 0, pkg.loaders[self])
-            return mi.next()
-    else:
-        def getHeader(self, pkg):
+        else:
             mi = getTS().dbMatch(0, pkg.loaders[self])
+        try:
             return mi.next()
+        except StopIteration:
+            class NullHeader(object):
+                def __getitem__(self, key):
+                    return None
+            return NullHeader()
 
     def getURL(self):
         return None
