@@ -98,7 +98,8 @@ class PackageChannel(Channel):
     def removeLoaders(self):
         for loader in self._loaders:
             cache = loader.getCache()
-            cache.removeLoader(loader)
+            if cache is not None:
+                cache.removeLoader(loader)
         del self._loaders[:]
         self._digest = object()
 
@@ -263,7 +264,7 @@ def parseChannelsDescription(data):
             current = {}
             channels[alias] = current
         elif current is not None and not line[0] == "#" and "=" in line:
-            key, value = line.split("=")
+            key, value = line.split("=", 1)
             current[key.strip().lower()] = value.strip()
     for alias in channels:
         channels[alias] = parseChannelData(channels[alias])
@@ -295,10 +296,12 @@ def getAllChannelInfos():
     from smart import channels
     filenames = os.listdir(os.path.dirname(channels.__file__))
     infos = {}
+    display_channels = sysconf.get("display-channels", True)
     for filename in filenames:
         if filename.endswith("_info.py"):
             type = filename[:-8].replace("_", "-")
-            infos[type] = getChannelInfo(type)
+            if display_channels == True or type in str(display_channels):
+                infos[type] = getChannelInfo(type)
     return infos
 
 def detectLocalChannels(path):
