@@ -30,12 +30,16 @@ Repository created for Mandriva's URPMI package manager.
 """)
 
 fields = [("baseurl", _("Base URL"), str, None,
-           _("Base URL where packages or the 'list' file are found under. "
+           _("Base URL where packages are found under. "
              "Using ' with <hdlurl>' pattern is also supported.")),
+          ("directory", _("With directory"), str, "",
+           _("Directory path for Base URL")),
           ("hdlurl", _("Header List URL"), str, "",
            _("URL for header list (hdlist or synthesis). If it's hdlist.cz "
              "inside the given base URL, may be left empty. URLs relative "
-             "to the Base URL are supported"))]
+             "to the Base URL are supported")),
+          ("mirrorurl", _("Mirror List URL"), str, "",
+           _("URL for mirror list)..."))]
 
 def postParse(data):
     import re
