@@ -86,7 +86,7 @@ def format_fields(fields):
             result.append(line)
     return "\n".join(result)
 
-def parse_options(argv):
+def option_parser():
     description = DESCRIPTION % {"types": build_types()}
     parser = OptionParser(usage=USAGE,
                           description=description,
@@ -96,7 +96,9 @@ def parse_options(argv):
     parser.defaults["remove"] = None
     parser.defaults["enable"] = None
     parser.defaults["disable"] = None
+    parser.defaults["list"] = None
     parser.defaults["show"] = None
+    parser.defaults["yaml"] = None
     parser.add_option("--add", action="callback", callback=append_all,
                       help=_("argument is an alias and one or more "
                              "key=value pairs defining a channel, or a "
@@ -111,9 +113,13 @@ def parse_options(argv):
                       help=_("arguments are channel aliases to be removed"))
     parser.add_option("--remove-all", action="store_true",
                       help=_("remove all existent channels"))
+    parser.add_option("--list", action="callback", callback=append_all,
+                      help=_("list all known channel aliases"))
     parser.add_option("--show", action="callback", callback=append_all,
                       help=_("show channels with given aliases, or all "
                            "channels if no arguments were given"))
+    parser.add_option("--yaml", action="callback", callback=append_all,
+                      help=_("show given channels in YAML format"))
     parser.add_option("--edit", action="store_true",
                       help=_("edit channels in editor set by $EDITOR"))
     parser.add_option("--enable", action="callback", callback=append_all,
@@ -124,6 +130,10 @@ def parse_options(argv):
                       help=_("execute without asking"))
     parser.add_option("--help-type", action="store", metavar="TYPE",
                       help=_("show further information about given type"))
+    return parser
+
+def parse_options(argv):
+    parser = option_parser()
     opts, args = parser.parse_args(argv)
     opts.args = args
     return opts
@@ -143,7 +153,8 @@ def main(ctrl, opts):
         print
         sys.exit(0)
 
-    if sysconf.getReadOnly() is True and opts.show is None:
+    if (sysconf.getReadOnly() is True and opts.list is None and
+                              opts.show is None and opts.yaml is None):
         iface.warning(_("Can't edit channels information."))
         raise Error, _("Configuration is in readonly mode.")
     
@@ -297,6 +308,14 @@ def main(ctrl, opts):
             else:
                 sysconf.set(("channels", alias, "disabled"), "yes")
 
+    if opts.list is not None:
+        for alias in (opts.list or sysconf.get("channels", ())):
+            channel = sysconf.get(("channels", alias))
+            if not channel:
+                iface.warning(_("Channel '%s' not found.") % alias)
+            else:
+                print alias
+
     if opts.show is not None:
         for alias in (opts.show or sysconf.get("channels", ())):
             channel = sysconf.get(("channels", alias))
@@ -309,6 +328,18 @@ def main(ctrl, opts):
                     print desc
                     print
 
+    if opts.yaml is not None:
+        import yaml
+        yamlchannels = {}
+        for alias in (opts.yaml or sysconf.get("channels", ())):
+            channel = sysconf.get(("channels", alias))
+            if not channel:
+                iface.warning(_("Channel '%s' not found.") % alias)
+            else:
+                data = parseChannelData(channel)
+                yamlchannels[alias] = data    
+        print yaml.dump(yamlchannels)
+
     if opts.edit:
         sysconf.assertWritable()
         
