@@ -45,11 +45,12 @@ smart query pkgname --show-requires
 smart query --requires libpkg.so --show-providedby
 smart query --installed
 smart query --summary ldap
+smart query --show-format='Name: $name\tVersion: $version\n'
 """)
 
-def parse_options(argv, help=None):
-    if help:
-        parser = OptionParser(help=help)
+def option_parser(**kwargs):
+    if kwargs:
+        parser = OptionParser(**kwargs)
     else:
         parser = OptionParser(usage=USAGE,
                               description=DESCRIPTION,
@@ -82,6 +83,8 @@ def parse_options(argv, help=None):
                       help=_("show only packages which match given group"))
     parser.add_option("--channel", action="append", default=[], metavar="STR",
                       help=_("show only packages from the given channel"))
+    parser.add_option("--flag", action="append", default=[], metavar="STR",
+                      help=_("show only packages with the given flag set"))
     parser.add_option("--summary", action="append", default=[], metavar="STR",
                       help=_("show only packages which match given summary"))
     parser.add_option("--description", action="append", default=[], metavar="STR",
@@ -123,16 +126,25 @@ def parse_options(argv, help=None):
                       help=_("show channels that include this package"))
     parser.add_option("--show-all", action="store_true",
                       help=_("enable all --show-* options"))
+    parser.add_option("--show-format", action="store", default=None,
+                      metavar="TMPL", help=_("show using string template"))
     parser.add_option("--format", action="store", default="text",
                       metavar="FMT", help=_("change output format"))
     parser.add_option("--output", action="store", metavar="FILE",
                       help=_("redirect output to given filename"))
+    return parser
+
+def parse_options(argv, **kwargs):
+    parser = option_parser(**kwargs)
     opts, args = parser.parse_args(argv)
     opts.args = args
     if opts.show_all:
         for attr in dir(opts):
-            if attr.startswith("show_") and attr != "show_prerequires":
+            if attr.startswith("show_") and attr != "show_prerequires" \
+                                        and attr != "show_format":
                 setattr(opts, attr, True)
+    if opts.show_format:
+        opts.show_format = string.Template(opts.show_format)
     return opts
 
 def main(ctrl, opts, reloadchannels=True):
@@ -302,37 +314,43 @@ def main(ctrl, opts, reloadchannels=True):
                             newpackages[pkg] = True
         packages = newpackages.keys()
 
+    def sh2re(pattern, stripeol=True, joinspace=True):
+        """ Convert the shell-style pattern to a regular expression. """
+        pattern = fnmatch.translate(pattern)
+        if stripeol:
+            if pattern.endswith("$"):
+                pattern = pattern[:-1]
+            elif pattern.endswith('\Z(?ms)'):
+                pattern = pattern[:-7]
+        pattern = pattern.replace(r"\ ", " ")
+        if joinspace:
+            pattern = r"\s+".join(pattern.split())
+        return re.compile(pattern, re.I)
+
     hasname = []
     for token in opts.name:
-        token = fnmatch.translate(token)[:-1].replace(r"\ ", " ")
-        token = r"\s+".join(token.split())
-        hasname.append(re.compile(token, re.I))
+        hasname.append(sh2re(token))
     hasgroup = []
     for token in opts.group:
-        token = fnmatch.translate(token)[:-1].replace(r"\ ", " ")
-        token = r"\s+".join(token.split())
-        hasgroup.append(re.compile(token, re.I))
+        hasgroup.append(sh2re(token))
     haschannel = []
     for token in opts.channel:
         haschannel.append(token)
+    hasflag = []
+    for token in opts.flag:
+        hasflag.append(token)
     hassummary = []
     for token in opts.summary:
-        token = fnmatch.translate(token)[:-1].replace(r"\ ", " ")
-        token = r"\s+".join(token.split())
-        hassummary.append(re.compile(token, re.I))
+        hassummary.append(sh2re(token))
     hasdescription = []
     for token in opts.description:
-        token = fnmatch.translate(token)[:-1].replace(r"\ ", " ")
-        token = r"\s+".join(token.split())
-        hasdescription.append(re.compile(token, re.I))
+        hasdescription.append(sh2re(token))
     haspath = []
     for token in opts.path:
-        token = fnmatch.translate(token).replace(r"\ ", " ")
-        haspath.append(re.compile(token, re.I))
+        haspath.append(sh2re(token, stripeol=False, joinspace=False))
     hasurl = []
     for token in opts.url:
-        token = fnmatch.translate(token)[:-1].replace(r"\ ", " ")
-        hasurl.append(re.compile(token, re.I))
+        haspath.append(sh2re(token, joinspace=False))
 
     if hasname or hasgroup or hassummary or hasdescription or haspath or hasurl:
         newpackages = {}
@@ -366,6 +384,16 @@ def main(ctrl, opts, reloadchannels=True):
                         for url in info.getReferenceURLs():
                             if pattern.match(url):
                                 newpackages[pkg] = True
+            if hasflag and not (hasname or needsinfo):
+                for flag in hasflag:
+                    if pkgconf.testFlag(flag, pkg):
+                        newpackages[pkg] = True
+            elif hasflag and pkg in newpackages:
+                for flag in hasflag:
+                    if not pkgconf.testFlag(flag, pkg):
+                        del newpackages[pkg]
+                        break
+        
         packages = newpackages.keys()
 
     if haschannel:
@@ -377,6 +405,14 @@ def main(ctrl, opts, reloadchannels=True):
                     newpackages[pkg] = True
         packages = newpackages.keys()
 
+    if hasflag:
+        newpackages = {}
+        for pkg in packages:
+            for flag in hasflag:
+                if pkgconf.testFlag(flag, pkg):
+                    newpackages[pkg] = True
+        packages = newpackages.keys()
+
     format = opts.format.lower()+"output"
     for attr, value in globals().items():
         if attr.lower() == format:
@@ -577,6 +613,25 @@ class TextOutput(NullOutput):
         print
 
     def showPackage(self, pkg):
+        self._firstprovides = True
+        self._firstrequiredby = True
+        self._firstupgradedby = True
+        self._firstconflictedby = True
+        self._firstrequires = True
+        self._firstrequiresprovidedby = True
+        self._firstupgrades = True
+        self._firstupgradesprovidedby = True
+        self._firstconflicts = True
+        self._firstconflictsprovidedby = True
+
+        if self.opts.show_format:
+            info = pkg.loaders.keys()[0].getInfo(pkg)
+            tags = dict(name=pkg.name, version=pkg.version,
+                        group=info.getGroup(), summary=info.getSummary())
+            fmt = self.opts.show_format.safe_substitute(tags)
+            fmt = fmt.replace('\\t', "\t").replace('\\n', "\n")
+            sys.stdout.write(fmt)
+            return
         if self.opts.hide_version:
             print pkg.name,
         else:
@@ -594,17 +649,6 @@ class TextOutput(NullOutput):
             print "-", info.getSummary(),
         print
 
-        self._firstprovides = True
-        self._firstrequiredby = True
-        self._firstupgradedby = True
-        self._firstconflictedby = True
-        self._firstrequires = True
-        self._firstrequiresprovidedby = True
-        self._firstupgrades = True
-        self._firstupgradesprovidedby = True
-        self._firstconflicts = True
-        self._firstconflictsprovidedby = True
-
     def showProvides(self, pkg, prv):
         self._firstrequiredby = True
         self._firstupgradedby = True
