@@ -41,7 +41,7 @@ smart remove pkgname-1.0-1
 smart remove pkgname1 pkgname2
 """)
 
-def parse_options(argv):
+def option_parser():
     parser = OptionParser(usage=USAGE,
                           description=DESCRIPTION,
                           examples=EXAMPLES)
@@ -58,9 +58,16 @@ def parse_options(argv):
                              "when possible"))
     parser.add_option("-y", "--yes", action="store_true",
                       help=_("do not ask for confirmation"))
+    parser.add_option("--auto", action="store_true",
+                      help=_("use the auto-install information to "
+                             "remove stuff."))
     parser.add_option("--dump", action="store_true",
                       help=_("dump package names and versions to stderr but "
                              "don't commit operation"))
+    return parser
+
+def parse_options(argv):
+    parser = option_parser()
     opts, args = parser.parse_args(argv)
     opts.args = args
     return opts
@@ -79,6 +86,12 @@ def main(ctrl, opts):
     cache = ctrl.getCache()
     trans = Transaction(cache, PolicyRemove)
     policy = trans.getPolicy()
+
+    if opts.auto:
+        rmcs = ctrl.markAndSweep()
+        confirm = not opts.yes
+        ctrl.commitChangeSet(rmcs, confirm=confirm)
+    
     for arg in opts.args:
 
         ratio, results, suggestions = ctrl.search(arg)
