@@ -19,7 +19,8 @@
 # along with Smart Package Manager; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-from smart.transaction import Transaction, PolicyUpgrade, UPGRADE
+from smart.transaction import Transaction, PolicyUpgrade, \
+                              UPGRADE, INSTALL, REMOVE
 from smart.option import OptionParser
 from smart.cache import Package
 from smart import *
@@ -34,6 +35,10 @@ DESCRIPTION=_("""
 This command will upgrade one or more packages which
 are currently installed in the system. If no packages
 are given, all installed packages will be checked.
+
+If pkgname is prefixed by a '+', it will be installed
+even if it was not currently installed in the system.
+If pkgname is prefixed with a '-', it will be removed.
 """)
 
 EXAMPLES=_("""
@@ -45,10 +50,11 @@ smart upgrade pkgname-1.0-1
 smart upgrade pkgname1 pkgname2
 """)
 
-def parse_options(argv):
+def option_parser():
     parser = OptionParser(usage=USAGE,
                           description=DESCRIPTION,
                           examples=EXAMPLES)
+    parser.allow_interspersed_args = False
     parser.add_option("--stepped", action="store_true",
                       help=_("split operation in steps"))
     parser.add_option("--urls", action="store_true",
@@ -68,11 +74,17 @@ def parse_options(argv):
     parser.add_option("--explain", action="store_true",
                       help=_("include additional information about changes,"
                              "when possible"))
+    parser.add_option("--flag", action="store", default=None,
+                      help=_("check only upgrades with the given flag set"))
     parser.add_option("-y", "--yes", action="store_true",
                       help=_("do not ask for confirmation"))
     parser.add_option("--dump", action="store_true",
                       help=_("dump package names and versions to stderr but "
                              "don't commit operation"))
+    return parser
+
+def parse_options(argv):
+    parser = option_parser()
     opts, args = parser.parse_args(argv)
     opts.args = args
     return opts
@@ -96,6 +108,14 @@ def main(ctrl, opts):
 
         for arg in opts.args:
 
+            op = UPGRADE
+            if arg.startswith('+'):
+                arg = arg[1:]
+                op = INSTALL
+            if arg.startswith('-'):
+                arg = arg[1:]
+                op = REMOVE
+
             ratio, results, suggestions = ctrl.search(arg)
 
             if not results:
@@ -103,11 +123,11 @@ def main(ctrl, opts):
                     dct = {}
                     for r, obj in suggestions:
                         if isinstance(obj, Package):
-                            if obj.installed:
+                            if obj.installed or op == INSTALL:
                                 dct[obj] = True
                         else:
                             for pkg in obj.packages:
-                                if pkg.installed:
+                                if pkg.installed or op == INSTALL:
                                     dct[pkg] = True
                     if not dct:
                         del suggestions[:]
@@ -122,23 +142,23 @@ def main(ctrl, opts):
             foundinstalled = False
             for obj in results:
                 if isinstance(obj, Package):
-                    if obj.installed:
-                        trans.enqueue(obj, UPGRADE)
-                        foundinstalled = True
+                    if (obj.installed or op == INSTALL) and (not opts.flag or pkgconf.testFlag(opts.flag, obj)):
+                        trans.enqueue(obj, op)
+                        foundinstalled = obj.installed
                     foundany = True
             if not foundany:
                 for obj in results:
                     if not isinstance(obj, Package):
                         for pkg in obj.packages:
-                            if pkg.installed:
-                                foundinstalled = True
-                                trans.enqueue(pkg, UPGRADE)
+                            if (pkg.installed or op == INSTALL) and (not opts.flag or pkgconf.testFlag(opts.flag, pkg)):
+                                foundinstalled = pkg.installed
+                                trans.enqueue(pkg, op)
                             foundany = True
-            if not foundinstalled:
+            if not foundinstalled and op != INSTALL:
                 iface.warning(_("'%s' matches no installed packages") % arg)
     else:
         for pkg in cache.getPackages():
-            if pkg.installed:
+            if pkg.installed and (not opts.flag or pkgconf.testFlag(opts.flag, pkg)):
                 trans.enqueue(pkg, UPGRADE)
 
     iface.showStatus(_("Computing transaction..."))
