@@ -34,6 +34,8 @@ import thread
 import time
 import os
 import re
+import signal
+import threading
 
 MAXRETRIES = 30
 SPEEDDELAY = 1
@@ -182,9 +184,17 @@ class Fetcher(object):
     def run(self, what=None, progress=None):
         socket.setdefaulttimeout(sysconf.get("socket-timeout", SOCKETTIMEOUT))
         self._cancel = False
+        thread_name = threading.currentThread().getName()
+        if thread_name == "MainThread":
+            def quitIntHandler(signal, frame):
+                print '\nInterrupted\n'
+                sys.exit(0)
+            old_quit_handler = signal.signal(signal.SIGQUIT, quitIntHandler)
+            old_int_handler  = signal.signal(signal.SIGINT, quitIntHandler)
         self._activedownloads = 0
         self._maxactivedownloads = sysconf.get("max-active-downloads",
                                                MAXACTIVEDOWNLOADS)
+        self._maxdownloadrate = sysconf.get("max-download-rate", 0)
         self.time = time.time()
         handlers = self._handlers.values()
         total = len(self._items)
@@ -285,6 +295,9 @@ class Fetcher(object):
             handler.stop()
         if not progress:
             prog.stop()
+        if thread_name == "MainThread":
+            signal.signal(signal.SIGQUIT, old_quit_handler)
+            signal.signal(signal.SIGINT, old_int_handler)
         if self._cancel:
             raise FetcherCancelled, _("Cancelled")
 
@@ -383,23 +396,24 @@ class Fetcher(object):
                 if lfilemd5 != filemd5:
                     raise Error, _("Invalid MD5 (expected %s, got %s)") % \
                                  (filemd5, lfilemd5)
+
+            filesha256 = item.getInfo(uncompprefix+"sha256")
+            if filesha256:
+                try:
+                    from hashlib import sha256
+                except ImportError:
+                    from smart.util.sha256 import sha256
+                digest = sha256()
+                file = open(localpath)
+                data = file.read(BLOCKSIZE)
+                while data:
+                    digest.update(data)
+                    data = file.read(BLOCKSIZE)
+                lfilesha256 = digest.hexdigest()
+                if lfilesha256 != filesha256:
+                   raise Error, _("Invalid SHA256 (expected %s, got %s)") % \
+                                 (filesha256, lfilesha256)
             else:
-                filesha256 = item.getInfo(uncompprefix+"sha256")
-                if filesha256:
-                    try:
-                        from hashlib import sha256
-                        digest = sha256()
-                        file = open(localpath)
-                        data = file.read(BLOCKSIZE)
-                        while data:
-                            digest.update(data)
-                            data = file.read(BLOCKSIZE)
-                        lfilesha256 = digest.hexdigest()
-                        if lfilesha256 != filesha256:
-                           raise Error, _("Invalid SHA256 (expected %s, got %s)") % \
-                                         (filesha256, lfilesha256)
-                    except ImportError:
-                        pass
                 filesha = item.getInfo(uncompprefix+"sha")
                 if filesha:
                     try:
@@ -1014,7 +1028,7 @@ class FTPHandler(FetcherHandler):
                 if resp[:3] == "213":
                     mtimes = resp[3:].strip()
                     mtime = time.mktime(time.strptime(mtimes, "%Y%m%d%H%M%S"))
-            except (ftplib.Error, ValueError):
+            except (ftplib.Error, ValueError, AttributeError):
                 pass
 
             try:
@@ -1135,6 +1149,7 @@ class URLLIBHandler(FetcherHandler):
 
     def fetch(self):
         import urllib, rfc822, calendar
+        from time import time, sleep
 
         class Opener(urllib.FancyURLopener):
             user = None
@@ -1239,6 +1254,11 @@ class URLLIBHandler(FetcherHandler):
                 except (IOError, OSError), e:
                     raise IOError, "%s: %s" % (localpathpart, e)
 
+                rate_limit = self._fetcher._maxdownloadrate
+                if rate_limit:
+                    rate_limit /= self._active
+                    start = time()
+
                 try:
                     data = remote.read(BLOCKSIZE)
                     while data:
@@ -1247,6 +1267,14 @@ class URLLIBHandler(FetcherHandler):
                         local.write(data)
                         current += len(data)
                         item.progress(current, total)
+                        if rate_limit:
+                            elapsed_time = time() - start
+                            if elapsed_time != 0:
+                                rate = current / elapsed_time
+                                expected_time = current / rate_limit
+                                sleep_time = expected_time - elapsed_time
+                                if sleep_time > 0:
+                                    sleep(sleep_time)
                         data = remote.read(BLOCKSIZE)
                 finally:
                     local.close()
@@ -1585,6 +1613,8 @@ class PyCurlHandler(FetcherHandler):
                 multi.remove_handle(handle)
                 self._lock.release()
 
+                http_code = handle.getinfo(pycurl.HTTP_CODE)
+
                 del self._active[handle]
                 userhost = (url.user, url.host, url.port)
                 self._inactive[handle] = userhost
@@ -1598,6 +1628,9 @@ class PyCurlHandler(FetcherHandler):
                     self._queue.append(item)
                     self._activelimit[item.getURL().host] = handle.active
                     del self._inactive[handle]
+                elif http_code == 404:
+                    # Use a standard translatable error message.
+                    item.setFailed(_("File not found"))
                 else:
                     item.setFailed(errmsg)
 
@@ -1621,13 +1654,11 @@ class PyCurlHandler(FetcherHandler):
                         for handle in self._inactive:
                             if self._inactive[handle] == userhost:
                                 del self._inactive[handle]
-                                self._active[handle] = schemehost
                                 break
                         else:
                             if len(self._inactive) > self.MAXINACTIVE:
                                 del self._inactive[handle]
                             handle = pycurl.Curl()
-                            self._active[handle] = schemehost
 
                         localpath = self.getLocalPath(item)
                         localpathpart = localpath+".part"
@@ -1653,6 +1684,8 @@ class PyCurlHandler(FetcherHandler):
                             local = open(localpathpart, openmode)
                         except (IOError, OSError), e:
                             item.setFailed("%s: %s" % (localpathpart, e))
+                            del self._active[handle]
+                            self.changeActiveDownloads(-1)
                             continue
 
                         handle.item = item
@@ -1683,6 +1716,7 @@ class PyCurlHandler(FetcherHandler):
                         handle.setopt(pycurl.MAXREDIRS, 5)
                         handle.setopt(pycurl.HTTPHEADER, ["Pragma:"])
                         handle.setopt(pycurl.USERAGENT, "smart/" + VERSION)
+                        handle.setopt(pycurl.FAILONERROR, 1)
 
                         # check if we have a valid local file and use I-M-S
                         if fetcher.validate(item, localpath):
@@ -1696,7 +1730,13 @@ class PyCurlHandler(FetcherHandler):
                             # reset the I-M-S option 
                             handle.setopt(pycurl.TIMECONDITION,
                                           pycurl.TIMECONDITION_NONE)
+                                          
+                        rate_limit = self._fetcher._maxdownloadrate
+                        if rate_limit:
+                            rate_limit /= self._active
+                            handle.setopt(pycurl.MAX_RECV_SPEED_LARGE, rate_limit)
 
+                        self._active[handle] = schemehost
                         self._lock.acquire()
                         multi.add_handle(handle)
                         self._lock.release()
@@ -1713,7 +1753,7 @@ class PyCurlHandler(FetcherHandler):
             while res == mp:
                 res, num = multi.perform()
             self._lock.release()
-            time.sleep(0.2)
+            multi.select(1.0)
         # Keep in mind that even though the while above has exited due to
         # self._active being False, it may actually be true *here* due to
         # race conditions.
@@ -1722,12 +1762,16 @@ class PyCurlHandler(FetcherHandler):
 try:
     import pycurl
 except ImportError:
-    pass
-else:
-    schemes = pycurl.version_info()[8]
-    for scheme in schemes:
-        if scheme != "file":
-            Fetcher.setHandler(scheme, PyCurlHandler)
+    pycurl = None
+
+def enablePycurl():
+    if pycurl:
+        schemes = pycurl.version_info()[8]
+        for scheme in schemes:
+            if scheme != "file":
+                Fetcher.setHandler(scheme, PyCurlHandler)
+
+hooks.register("enable-pycurl", enablePycurl)
 
 class SCPHandler(FetcherHandler):
 
