@@ -28,6 +28,7 @@ from smart.interfaces.gtk.flags import GtkFlags
 from smart.interfaces.gtk.priorities import GtkPriorities, GtkSinglePriority
 from smart.interfaces.gtk.packageview import GtkPackageView
 from smart.interfaces.gtk.packageinfo import GtkPackageInfo
+from smart.interfaces.gtk.legend import GtkLegend
 from smart.interfaces.gtk.interface import GtkInterface
 from smart.interfaces.gtk import getPixbuf
 from smart.const import NEVER, VERSION
@@ -36,7 +37,11 @@ from smart.cache import Package
 from smart import *
 import shlex, re
 import fnmatch
-import gtk
+import gobject, gtk
+try:
+    import sexy
+except ImportError:
+    sexy = None
 
 UI = """
 <ui>
@@ -58,6 +63,7 @@ UI = """
         <separator/>
         <menuitem action="upgrade-all"/>
         <menuitem action="fix-all-problems"/>
+        <menuitem action="remove-auto"/>
         <separator/>
         <menuitem action="check-installed-packages"/>
         <menuitem action="check-uninstalled-packages"/>
@@ -72,10 +78,12 @@ UI = """
     </menu>
     <menu action="view">
         <menuitem action="hide-non-upgrades"/>
+        <menuitem action="hide-non-newest"/>
         <menuitem action="hide-installed"/>
         <menuitem action="hide-uninstalled"/>
         <menuitem action="hide-unmarked"/>
         <menuitem action="hide-unlocked"/>
+        <menuitem action="hide-requested"/>
         <menuitem action="hide-old"/>
         <separator/>
         <menuitem action="expand-all"/>
@@ -83,6 +91,7 @@ UI = """
         <separator/>
         <menu action="tree-style">
             <menuitem action="tree-style-groups"/>
+            <menuitem action="tree-style-separate-groups"/>
             <menuitem action="tree-style-channels"/>
             <menuitem action="tree-style-channels-groups"/>
             <menuitem action="tree-style-none"/>
@@ -92,6 +101,7 @@ UI = """
         <menuitem action="log-window"/>
     </menu>
     <menu action="help">
+        <menuitem action="legend-window"/>
         <menuitem action="about"/>
     </menu>   
 </menubar>
@@ -141,6 +151,8 @@ ACTIONS = [
      _("Upgrade all packages"), "self.upgradeAll()"),
     ("fix-all-problems", None, _("Fix All _Problems..."), None,
      _("Fix all problems"), "self.fixAllProblems()"),
+    ("remove-auto", None, _("Remove Automatic..."), None,
+     _("Remove packages installed as dependencies"), "self.removeAuto()"),
     ("find", "gtk-find", _("_Find..."), "<control>f",
      _("Find packages"), "self.toggleSearch()"),
     ("edit-channels", None, _("_Channels"), None,
@@ -164,6 +176,8 @@ ACTIONS = [
      _("Show log window"), "self.showLog()"),
 
     ("help", None, _("_Help")),
+    ("legend-window", None, _("_Icon Legend"), None,
+     _("Show icon legend"), "self.showLegend()"),
     ("about", None, _("_About"), None,
      _("Show about window"), "self.showAbout()"),
 
@@ -219,10 +233,12 @@ class GtkInteractiveInterface(GtkInterface):
 
         self._filters = {}
         for name, label in [("hide-non-upgrades", _("Hide Non-upgrades")),
+                            ("hide-non-newest", _("Hide Non-newest")),
                             ("hide-installed", _("Hide Installed")),
                             ("hide-uninstalled", _("Hide Uninstalled")),
                             ("hide-unmarked", _("Hide Unmarked")),
                             ("hide-unlocked", _("Hide Unlocked")),
+                            ("hide-requested", _("Hide Requested")),
                             ("hide-old", _("Hide Old"))]:
             action = gtk.ToggleAction(name, label, "", "")
             action.connect("toggled", lambda x, y: self.toggleFilter(y), name)
@@ -231,6 +247,7 @@ class GtkInteractiveInterface(GtkInterface):
         treestyle = sysconf.get("package-tree")
         lastaction = None
         for name, label in [("groups", _("Groups")),
+                            ("separate-groups", _("Separate Groups")),
                             ("channels", _("Channels")),
                             ("channels-groups", _("Channels & Groups")),
                             ("none", _("None"))]:
@@ -252,6 +269,10 @@ class GtkInteractiveInterface(GtkInterface):
         self._toolbar = self._ui.get_widget("/toolbar")
         self._toolbar.set_style(gtk.TOOLBAR_ICONS)
         self._topvbox.pack_start(self._toolbar, False)
+        if sysconf.getReadOnly():
+           # Can't update channels in readonly mode.
+           updatetoolitem = self._ui.get_widget("/toolbar/update-channels")
+           updatetoolitem.set_property("sensitive", False)
 
         self._window.add_accel_group(self._ui.get_accel_group())
 
@@ -266,78 +287,169 @@ class GtkInteractiveInterface(GtkInterface):
 
         # Search bar
 
-        self._searchbar = gtk.Alignment()
-        self._searchbar.set(0, 0, 1, 1)
-        self._searchbar.set_padding(3, 3, 0, 0)
-        self._topvbox.pack_start(self._searchbar, False)
+        if gtk.gtk_version >= (2, 16, 0) or sexy:
+            self._searchbar = gtk.ToolItem()
+            self._searchbar.set_expand(True)
+            self._searchbar.set_homogeneous(False)
+            self._searchbar.show()
+            count = self._toolbar.get_n_items()
+            find = self._toolbar.get_nth_item(count - 1)
+            self._toolbar.remove(find)
+            self._toolbar.insert(self._searchbar, -1)
 
-        searchvp = gtk.Viewport()
-        searchvp.set_shadow_type(gtk.SHADOW_OUT)
-        searchvp.show()
-        self._searchbar.add(searchvp)
+            searchtable = gtk.Table(1, 1)
+            searchtable.set_row_spacings(5)
+            searchtable.set_col_spacings(5)
+            searchtable.set_border_width(5)
+            searchtable.show()
+            self._searchbar.add(searchtable)
 
-        searchtable = gtk.Table(1, 1)
-        searchtable.set_row_spacings(5)
-        searchtable.set_col_spacings(5)
-        searchtable.set_border_width(5)
-        searchtable.show()
-        searchvp.add(searchtable)
+            if gtk.gtk_version >= (2, 16, 0):
+                self._searchentry = gtk.Entry()
+                self._searchentry.set_property("primary-icon-name", "gtk-find")
+                self._searchentry.set_property("secondary-icon-name", "gtk-clear")
+                def press(entry, icon_pos, event):
+                    if int(icon_pos) == 0: # "primary"
+                        self._searchmenu.popup(None, None, None, event.button, event.time)
+                    elif int(icon_pos) == 1: # "secondary"
+                        self._searchentry.set_text("")
+                        self.refreshPackages()
+                self._searchentry.connect("icon-press", press)
+            elif sexy:
+                self._searchentry = sexy.IconEntry()
+                image = gtk.Image()
+                image.set_from_stock("gtk-find", gtk.ICON_SIZE_BUTTON)
+                self._searchentry.set_icon(sexy.ICON_ENTRY_PRIMARY, image)
+                image = gtk.Image()
+                image.set_from_stock("gtk-clear", gtk.ICON_SIZE_BUTTON)
+                self._searchentry.set_icon(sexy.ICON_ENTRY_SECONDARY, image)
+                def pressed(entry, icon_pos, button):
+                    if icon_pos == 0: # "primary"
+                        self._searchmenu.popup(None, None, None, button, gtk.get_current_event_time())
+                    elif icon_pos == 1: # "secondary"
+                        self._searchentry.set_text("")
+                        self.refreshPackages()
+                self._searchentry.connect("icon-pressed", pressed)
+            self._searchentry.connect("activate", lambda x: self.refreshPackages())
+            self._searchentry.show()
+            searchtable.attach(self._searchentry, 0, 1, 0, 1)
 
-        label = gtk.Label(_("Search:"))
-        label.show()
-        searchtable.attach(label, 0, 1, 0, 1, 0, 0)
+            self._searchmenu = gtk.Menu()
+            self._searchname = gtk.CheckMenuItem(_("Automatic"))
+            self._searchname.set_draw_as_radio(True)
+            self._searchname.set_active(True)
+            def search_automatic(item):
+                self._searchdesc.set_active(not item.get_active())
+                self.refreshPackages()
+            self._searchname.connect("activate", search_automatic)
+            self._searchname.show()
+            self._searchmenu.append(self._searchname)
+            self._searchdesc = gtk.CheckMenuItem(_("Description"))
+            self._searchdesc.set_draw_as_radio(True)
+            self._searchdesc.set_active(False)
+            def search_description(item):
+                self._searchname.set_active(not item.get_active())
+                self.refreshPackages()
+            self._searchdesc.connect("activate", search_description)
+            self._searchdesc.show()
+            self._searchmenu.append(self._searchdesc)
+        else:
+            self._searchbar = gtk.Alignment()
+            self._searchbar.set(0, 0, 1, 1)
+            self._searchbar.set_padding(3, 3, 0, 0)
+            self._topvbox.pack_start(self._searchbar, False)
 
-        self._searchentry = gtk.Entry()
-        self._searchentry.connect("activate", lambda x: self.refreshPackages())
-        self._searchentry.show()
-        searchtable.attach(self._searchentry, 1, 2, 0, 1)
+            searchvp = gtk.Viewport()
+            searchvp.set_shadow_type(gtk.SHADOW_OUT)
+            searchvp.show()
+            self._searchbar.add(searchvp)
 
-        button = gtk.Button()
-        button.set_relief(gtk.RELIEF_NONE)
-        button.connect("clicked", lambda x: self.refreshPackages())
-        button.show()
-        searchtable.attach(button, 2, 3, 0, 1, 0, 0)
-        image = gtk.Image()
-        image.set_from_stock("gtk-find", gtk.ICON_SIZE_BUTTON)
-        image.show()
-        button.add(image)
+            searchtable = gtk.Table(1, 1)
+            searchtable.set_row_spacings(5)
+            searchtable.set_col_spacings(5)
+            searchtable.set_border_width(5)
+            searchtable.show()
+            searchvp.add(searchtable)
 
-        align = gtk.Alignment()
-        align.set(1, 0, 0, 0)
-        align.set_padding(0, 0, 10, 0)
-        align.show()
-        searchtable.attach(align, 3, 4, 0, 1, gtk.FILL, gtk.FILL)
-        button = gtk.Button()
-        button.set_size_request(20, 20)
-        button.set_relief(gtk.RELIEF_NONE)
-        button.connect("clicked", lambda x: self.toggleSearch())
-        button.show()
-        align.add(button)
-        image = gtk.Image()
-        image.set_from_stock("gtk-close", gtk.ICON_SIZE_MENU)
-        image.show()
-        button.add(image)
+            label = gtk.Label(_("Search:"))
+            label.show()
+            searchtable.attach(label, 0, 1, 0, 1, 0, 0)
 
-        hbox = gtk.HBox()
-        hbox.set_spacing(10)
-        hbox.show()
-        searchtable.attach(hbox, 1, 2, 1, 2)
+            self._searchentry = gtk.Entry()
+            self._searchentry.connect("activate", lambda x: self.refreshPackages())
+            self._searchentry.show()
+            searchtable.attach(self._searchentry, 1, 2, 0, 1)
 
-        self._searchname = gtk.RadioButton(None, _("Automatic"))
-        self._searchname.set_active(True)
-        self._searchname.connect("clicked", lambda x: self.refreshPackages())
-        self._searchname.show()
-        hbox.pack_start(self._searchname, False)
-        self._searchdesc = gtk.RadioButton(self._searchname, _("Description"))
-        self._searchdesc.connect("clicked", lambda x: self.refreshPackages())
-        self._searchdesc.show()
-        hbox.pack_start(self._searchdesc, False)
+            button = gtk.Button()
+            button.set_relief(gtk.RELIEF_NONE)
+            button.connect("clicked", lambda x: self.refreshPackages())
+            button.show()
+            searchtable.attach(button, 2, 3, 0, 1, 0, 0)
+            image = gtk.Image()
+            image.set_from_stock("gtk-find", gtk.ICON_SIZE_BUTTON)
+            image.show()
+            button.add(image)
+
+            align = gtk.Alignment()
+            align.set(1, 0, 0, 0)
+            align.set_padding(0, 0, 10, 0)
+            align.show()
+            searchtable.attach(align, 3, 4, 0, 1, gtk.FILL, gtk.FILL)
+            button = gtk.Button()
+            button.set_size_request(20, 20)
+            button.set_relief(gtk.RELIEF_NONE)
+            button.connect("clicked", lambda x: self.toggleSearch())
+            button.show()
+            align.add(button)
+            image = gtk.Image()
+            image.set_from_stock("gtk-close", gtk.ICON_SIZE_MENU)
+            image.show()
+            button.add(image)
+
+            hbox = gtk.HBox()
+            hbox.set_spacing(10)
+            hbox.show()
+            searchtable.attach(hbox, 1, 2, 1, 2)
+
+            self._searchmenu = None
+            self._searchname = gtk.RadioButton(None, _("Automatic"))
+            self._searchname.set_active(True)
+            self._searchname.connect("clicked", lambda x: self.refreshPackages())
+            self._searchname.show()
+            hbox.pack_start(self._searchname, False)
+            self._searchdesc = gtk.RadioButton(self._searchname, _("Description"))
+            self._searchdesc.connect("clicked", lambda x: self.refreshPackages())
+            self._searchdesc.show()
+            hbox.pack_start(self._searchdesc, False)
 
         # Packages and information
 
+        self._hpaned = gtk.HPaned()
+        self._hpaned.show()
+        self._topvbox.pack_start(self._hpaned)
+
+        scrollwin = gtk.ScrolledWindow()
+        scrollwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
+        scrollwin.set_shadow_type(gtk.SHADOW_IN)
+        self._hpaned.pack1(scrollwin, True)
+
+        self._pg = gtk.TreeView()
+        def group_selected(treeview):
+            self.refreshPackages()
+        self._pg.connect("cursor_changed", group_selected)
+        self._pg.show()
+        scrollwin.add(self._pg)
+
+        selection = self._pg.get_selection()
+        selection.set_mode(gtk.SELECTION_MULTIPLE)
+
+        renderer = gtk.CellRendererText()
+        column = gtk.TreeViewColumn(_("Group"), renderer, text=1)
+        self._pg.append_column(column)
+
         self._vpaned = gtk.VPaned()
         self._vpaned.show()
-        self._topvbox.pack_start(self._vpaned)
+        self._hpaned.pack2(self._vpaned, True)
 
         self._pv = GtkPackageView()
         self._pv.show()
@@ -355,6 +467,8 @@ class GtkInteractiveInterface(GtkInterface):
         self._status = gtk.Statusbar()
         self._status.show()
         self._topvbox.pack_start(self._status, False)
+        
+        self._legend = GtkLegend()
 
     def showStatus(self, msg):
         self._status.pop(0)
@@ -386,6 +500,7 @@ class GtkInteractiveInterface(GtkInterface):
     def saveState(self):
         sysconf.set("gtk-size", self._window.get_size())
         #sysconf.set("gtk-position", self._window.get_position())
+        sysconf.set("gtk-hpaned-position", self._hpaned.get_position())
         sysconf.set("gtk-vpaned-position", self._vpaned.get_position())
 
     def loadState(self):
@@ -395,6 +510,9 @@ class GtkInteractiveInterface(GtkInterface):
         #var = sysconf.get("gtk-position")
         #if var is not None:
         #    self._window.move(*var)
+        var = sysconf.get("gtk-hpaned-position")
+        if var is not None:
+            self._hpaned.set_position(var)
         var = sysconf.get("gtk-vpaned-position")
         if var is not None:
             self._vpaned.set_position(var)
@@ -406,6 +524,8 @@ class GtkInteractiveInterface(GtkInterface):
         self.updateChannels(selected=True)
 
     def updateChannels(self, selected=False, channels=None):
+        if self._changeset is None:
+            return
         if selected:
             aliases = GtkChannelSelector().show()
             channels = [channel for channel in self._ctrl.getChannels()
@@ -418,6 +538,8 @@ class GtkInteractiveInterface(GtkInterface):
         self.refreshPackages()
 
     def rebuildCache(self):
+        if self._changeset is None:
+            return
         state = self._changeset.getPersistentState()
         self._ctrl.reloadChannels()
         self._changeset.setPersistentState(state)
@@ -448,6 +570,9 @@ class GtkInteractiveInterface(GtkInterface):
     def showLog(self):
         return self._log.show()
 
+    def showLegend(self):
+        return self._legend.show()
+
     def expandPackages(self):
         self._pv.getTreeView().expand_all()
 
@@ -481,6 +606,17 @@ class GtkInteractiveInterface(GtkInterface):
         else:
             self.showStatus(_("No interesting upgrades available!"))
 
+    def removeAuto(self):
+        changeset = self._ctrl.markAndSweep()
+        if changeset != self._changeset:
+            if self.confirmChange(self._changeset, changeset):
+                self.saveUndo()
+                self._changeset.setState(changeset)
+                self.changedMarks()
+                self.applyChanges(confirm=True)
+        else:
+            self.showStatus(_("No automatic removals possible!"))
+
     def actOnPackages(self, pkgs, op=None):
         cache = self._ctrl.getCache()
         transaction = Transaction(cache, policy=PolicyInstall)
@@ -727,7 +863,10 @@ class GtkInteractiveInterface(GtkInterface):
 
     def setTreeStyle(self, mode):
         if mode != sysconf.get("package-tree"):
-            sysconf.set("package-tree", mode)
+            if not sysconf.getReadOnly():
+                sysconf.set("package-tree", mode)
+            else:
+                sysconf.set("package-tree", mode, weak=True)
             self.refreshPackages()
 
     def editChannels(self):
@@ -760,8 +899,12 @@ class GtkInteractiveInterface(GtkInterface):
         self._clearmenuitem.set_property("sensitive", bool(self._changeset))
 
     def toggleSearch(self):
-        visible = not self._searchbar.get_property('visible')
-        self._searchbar.set_property('visible', visible)
+        if not isinstance(self._searchbar, gtk.ToolItem):
+            visible = not self._searchbar.get_property('visible')
+            self._searchbar.set_property('visible', visible)
+        else:
+            # always show the ToolItem
+            visible = True
         self.refreshPackages()
         if visible:
             self._searchentry.grab_focus()
@@ -776,6 +919,47 @@ class GtkInteractiveInterface(GtkInterface):
         ctrl = self._ctrl
         changeset = self._changeset
 
+        self._pg.parent.set_property('visible', tree == "separate-groups")
+        if self._pg.get_property('visible'):
+            model = self._pg.get_model()
+            if not model:
+                packages = ctrl.getCache().getPackages()
+                packagegroups = {}
+                for pkg in packages:
+                    for loader in pkg.loaders:
+                        info = loader.getInfo(pkg)
+                        group = info.getGroup()
+                        if group in packagegroups:
+                            packagegroups[group] += 1
+                        else:
+                            packagegroups[group] = 1
+
+                groups = []
+                names = {}
+                all = "%s (%d)" % (_("All"), len(packages))
+                for group, count in packagegroups.iteritems():
+                     displayicon = None
+                     displayname = "%s (%d)" % (group, count)
+                     groups.append(displayname)
+                     names[displayname] = group
+                groups.sort()
+                    
+                model = gtk.ListStore(gobject.TYPE_STRING,
+                                      gobject.TYPE_STRING)
+                self._pg.set_model(model)
+                iter = model.append()
+                model.set(iter, 0, None)
+                model.set(iter, 1, all)
+                self._pg.get_selection().select_iter(iter)
+                for group in groups:
+                    iter = model.append()
+                    model.set(iter, 0, names[group])
+                    model.set(iter, 1, group)
+                self._pg.queue_draw()
+
+        columns = sysconf.get("package-columns", "name,version")
+        self._pv.setVisibleColumns(columns.split(","))
+
         if self._searchbar.get_property("visible"):
 
             searcher = Searcher()
@@ -808,6 +992,8 @@ class GtkInteractiveInterface(GtkInterface):
                         packages.append(obj)
                     else:
                         packages.extend(obj.packages)
+            elif isinstance(self._searchbar, gtk.ToolItem):
+                packages = ctrl.getCache().getPackages()
         else:
             packages = ctrl.getCache().getPackages()
 
@@ -830,6 +1016,15 @@ class GtkInteractiveInterface(GtkInterface):
                         else:
                             newpackages.update(upgpkgs)
                 packages = newpackages.keys()
+            if "hide-non-newest" in filters:
+                newest = {}
+                for pkg in packages:
+                    if pkg.name in newest:
+                        if pkg > newest[pkg.name]:
+                            newest[pkg.name] = pkg
+                    else:
+                        newest[pkg.name] = pkg
+                packages = [pkg for pkg in packages if pkg == newest[pkg.name]]
             if "hide-uninstalled" in filters:
                 packages = [x for x in packages if x.installed]
             if "hide-unmarked" in filters:
@@ -838,6 +1033,8 @@ class GtkInteractiveInterface(GtkInterface):
                 packages = [x for x in packages if not x.installed]
             if "hide-unlocked" in filters:
                 packages = pkgconf.filterByFlag("lock", packages)
+            if "hide-requested" in filters:
+                packages = pkgconf.filterByFlag("auto", packages)
             if "hide-old" in filters:
                 packages = pkgconf.filterByFlag("new", packages)
 
@@ -857,6 +1054,30 @@ class GtkInteractiveInterface(GtkInterface):
                         else:
                             groups[group] = [pkg]
 
+        elif tree == "separate-groups":
+            showgroups = {}
+            selection = self._pg.get_selection()
+            model, paths = selection.get_selected_rows()
+            for path in paths:
+                iter = model.get_iter(path)
+                value = model.get_value(iter, 0)
+                showgroups[value] = True
+            if showgroups and None not in showgroups:
+                newpackages = []
+                done = {}
+                for pkg in packages:
+                    for loader in pkg.loaders:
+                        info = loader.getInfo(pkg)
+                        group = info.getGroup()
+                        donetuple = (group, pkg)
+                        if donetuple not in done:
+                            done[donetuple] = True
+                            if group in showgroups:
+                                newpackages.append(pkg)
+                groups = newpackages
+            else:
+                groups = packages
+
         elif tree == "channels":
             groups = {}
             done = {}
@@ -896,9 +1117,14 @@ class GtkInteractiveInterface(GtkInterface):
 
         self._pv.setPackages(groups, changeset, keepstate=True)
 
+        packages = ctrl.getCache().getPackages()
+        self.showStatus(_("%d packages, %d installed") %
+            (len(packages), len([pkg for pkg in packages if pkg.installed])))
+
         self.setBusy(False)
 
     def showAbout(widget):
+        copyright = "2010 Smart Team, 2006 Canonical Ltd., 2004 Conectiva, Inc."
         license = """
             This program is free software; you can redistribute it and/or modify
             it under the terms of the GNU General Public License as published by
@@ -915,16 +1141,29 @@ class GtkInteractiveInterface(GtkInterface):
             Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
             """
         credits=["""Gustavo Niemeyer - Original author and lead developer.""",
+           u"""Anders F Bj\u00f6rklund - Current maintainer and developer.""",
             """Conectiva Inc. - Original project funder up to August 2005.""",
-            """Canonical Ltd. - Funding Smart development since September of 2005.""",
+            """Canonical Ltd. - Funding Smart up to November of 2009.""",
+            """Unity Linux - Smart development and deployment support.""",
             """And many others - Check our website for the complete list.""",
             ]
-        website = "http://labix.org/smart"    
+        website = "http://smartpm.org/"
+
+        if gtk.pygtk_version < (2,6,0):
+             dialog = gtk.MessageDialog(buttons=gtk.BUTTONS_CLOSE)
+             dialog.set_markup("<b>Smart Package Manager %s</b>\n"
+                               "<small>(C) %s</small>\n" % (VERSION, copyright) +
+                               "<small>%s</small>\n" % license.replace(" " * 12, "") +
+                               "<span>%s</span>\n" % "\n".join(credits) +
+                               "\n<tt>%s</tt>" % website)
+             dialog.run()
+             dialog.destroy()
+             return
 
         aboutdialog = gtk.AboutDialog()
         aboutdialog.set_name("Smart Package Manager")
         aboutdialog.set_version(VERSION)
-        aboutdialog.set_copyright("2006 Canonical, 2004 Conectiva, Inc.")
+        aboutdialog.set_copyright(copyright)
         aboutdialog.set_authors(credits)
         aboutdialog.set_license(license)
         aboutdialog.set_website(website)
