@@ -24,6 +24,10 @@ from smart.progress import Progress, INTERVAL
 from smart.interfaces.gtk import getPixbuf
 from smart import *
 import gobject, gtk
+try:
+    import glib
+except ImportError:
+    glib = None
 import posixpath
 import thread
 import time
@@ -36,6 +40,9 @@ class GtkProgress(Progress, gtk.Window):
 
         self.connect("delete-event", lambda x,y: True)
 
+        # updates from subthreads not showing up [#592503]
+        self._threadsafe = not glib or glib.glib_version < (2, 24, 0)
+
         self._hassub = hassub
         self._shorturl = ShortURL(50)
         self._ticking = False
@@ -43,9 +50,15 @@ class GtkProgress(Progress, gtk.Window):
         self._fetcher = None
 
         if hassub:
-            self.set_size_request(500, 400)
+            self.set_size_request(500, 100)
+            self.set_default_size(500, 400)
         else:
             self.set_size_request(300, 80)
+        def configure_event(widget, event):
+            maxlen = widget.allocation.width / 10
+            self._shorturl = ShortURL(maxlen)
+            return False
+        self.connect("configure-event", configure_event)
 
         self.set_icon(getPixbuf("smart"))
         self.set_title(_("Operation Progress"))
@@ -69,12 +82,23 @@ class GtkProgress(Progress, gtk.Window):
         vbox.pack_start(self._progressbar, expand=False, fill=False)
 
         if hassub:
+            expander = gtk.Expander()
+            expander.set_expanded(True)
+            expander.show()
+            def toggle_window(expander, param_spec):
+                if expander.get_expanded():
+                    self.resize(500, 400)
+                else:
+                    self.resize(500, 100)
+            expander.connect("notify::expanded", toggle_window)
+            vbox.pack_start(expander)
+
             self._scrollwin = gtk.ScrolledWindow()
             self._scrollwin.set_policy(gtk.POLICY_AUTOMATIC,
                                        gtk.POLICY_AUTOMATIC)
             self._scrollwin.set_shadow_type(gtk.SHADOW_IN)
             self._scrollwin.show()
-            vbox.pack_start(self._scrollwin)
+            expander.add(self._scrollwin)
 
             self._treemodel = gtk.ListStore(gobject.TYPE_INT,
                                             gobject.TYPE_STRING,
@@ -86,8 +110,14 @@ class GtkProgress(Progress, gtk.Window):
             self._treeview.show()
             self._scrollwin.add(self._treeview)
 
-            renderer = ProgressCellRenderer()
-            column = gtk.TreeViewColumn(_("Progress"), renderer, percent=0)
+            if gtk.pygtk_version < (2,6,0):
+                renderer = ProgressCellRenderer()
+                column = gtk.TreeViewColumn(_("Progress"), renderer, percent=0)
+            else:
+                renderer = gtk.CellRendererProgress()
+                # don't display the percent label
+                renderer.set_property("text", "")
+                column = gtk.TreeViewColumn(_("Progress"), renderer, value=0)
             column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
             column.set_fixed_width(110)
             self._treeview.append_column(column)
@@ -151,8 +181,9 @@ class GtkProgress(Progress, gtk.Window):
     def tick(self):
         while not self._stopticking:
             self.lock()
-            while gtk.events_pending():
-                gtk.main_iteration()
+            if self._threadsafe:
+                while gtk.events_pending():
+                    gtk.main_iteration()
             self.unlock()
             time.sleep(INTERVAL)
         self._ticking = False
@@ -217,8 +248,8 @@ class GtkProgress(Progress, gtk.Window):
             if total:
                 self._totalcolumn.set_visible(True)
             if done:
-                speed = "Done"
-                eta = "Done"
+                speed = _("Done")
+                eta = _("Done")
             else:
                 speed = data.get("speed", "")
                 if speed:
@@ -237,6 +268,10 @@ class GtkProgress(Progress, gtk.Window):
             if self._hassub:
                 self._treeview.queue_draw()
 
+        if not self._threadsafe:
+            while gtk.events_pending():
+                gtk.main_iteration()
+
 gobject.type_register(GtkProgress)
 
 class ProgressCellRenderer(gtk.GenericCellRenderer):
