@@ -28,6 +28,7 @@ from smart.interfaces.qt.flags import QtFlags
 from smart.interfaces.qt.priorities import QtPriorities, QtSinglePriority
 from smart.interfaces.qt.packageview import QtPackageView
 from smart.interfaces.qt.packageinfo import QtPackageInfo
+from smart.interfaces.qt.legend import QtLegend
 from smart.interfaces.qt.interface import QtInterface, app
 from smart.interfaces.qt import getPixmap, centerWindow
 from smart.const import NEVER, VERSION
@@ -74,6 +75,7 @@ MENUBAR = [
         "hide-uninstalled",
         "hide-unmarked",
         "hide-unlocked",
+        "hide-requested",
         "hide-old",
         None,
         "expand-all",
@@ -90,6 +92,7 @@ MENUBAR = [
         "log-window"
     ] ),
    ( "help", [
+        "legend-window",
         "about",
     ] )
 ]
@@ -169,6 +172,8 @@ ACTIONS = [
      _("Show log window"), "self._log.show()"),
 
     ("help", None, _("_Help")),
+    ("legend-window", None, _("_Icon Legend"), None,
+     _("Show icon legend"), "self._legend.show()"),
     ("about", None, _("_About"), None,
      _("Show about window"), "self.showAbout()"),
 ]
@@ -253,6 +258,9 @@ def compileActions(group, actions, globals):
         if action[0] == "log-window": #HACK
             self = globals["self"]
             qt.QObject.connect(act, qt.SIGNAL("activated()"), self.showLog)
+        if action[0] == "legend-window": #HACK
+            self = globals["self"]
+            qt.QObject.connect(act, qt.SIGNAL("activated()"), self.showLegend)
         if action[0] == "about": #HACK
             self = globals["self"]
             qt.QObject.connect(act, qt.SIGNAL("activated()"), self.showAbout)
@@ -306,6 +314,7 @@ class QtInteractiveInterface(QtInterface):
                             ("hide-uninstalled", _("Hide Uninstalled")),
                             ("hide-unmarked", _("Hide Unmarked")),
                             ("hide-unlocked", _("Hide Unlocked")),
+                            ("hide-requested", _("Hide Requested")),
                             ("hide-old", _("Hide Old"))]:
             act = ToggleAction(None, name, label)
             act.connect("activated()", self.toggleFilter, name)
@@ -419,6 +428,8 @@ class QtInteractiveInterface(QtInterface):
 
         self._status = self._window.statusBar()
         self._status.show()
+        
+        self._legend = QtLegend(self._window)
 
     def showStatus(self, msg):
         self._status.message(msg)
@@ -510,6 +521,9 @@ class QtInteractiveInterface(QtInterface):
     def showLog(self):
         return self._log.show()
 
+    def showLegend(self):
+        return self._legend.show()
+
     def expandPackages(self):
         self._pv.expandAll()
 
@@ -919,6 +933,8 @@ class QtInteractiveInterface(QtInterface):
                 packages = [x for x in packages if not x.installed]
             if "hide-unlocked" in filters:
                 packages = pkgconf.filterByFlag("lock", packages)
+            if "hide-requested" in filters:
+                packages = pkgconf.filterByFlag("auto", packages)
             if "hide-old" in filters:
                 packages = pkgconf.filterByFlag("new", packages)
 
@@ -980,6 +996,7 @@ class QtInteractiveInterface(QtInterface):
         self.setBusy(False)
 
     def showAbout(self):
+        copyright = "2010 Smart Team, 2006 Canonical Ltd., 2004 Conectiva, Inc."
         license = """
             This program is free software; you can redistribute it and/or modify
             it under the terms of the GNU General Public License as published by
@@ -996,15 +1013,17 @@ class QtInteractiveInterface(QtInterface):
             Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
             """
         credits=["""Gustavo Niemeyer - Original author and lead developer.""",
+           u"""Anders F Bj\u00f6rklund - Current maintainer and developer.""",
             """Conectiva Inc. - Original project funder up to August 2005.""",
-            """Canonical Ltd. - Funding Smart development since September of 2005.""",
+            """Canonical Ltd. - Funded Smart up to November of 2009.""",
+            """Unity Linux - Smart development and deployment support.""",
             """And many others - Check our website for the complete list.""",
             ]
-        website = "http://labix.org/smart"    
+        website = "http://smartpm.org/"
 
         qt.QMessageBox.about(self._window, "About " + "Smart Package Manager",
             "<h2>" + "Smart Package Manager" + " " + VERSION + "</h2>" + \
-            "<p>Copyright &copy; " + "2006 Canonical, 2004 Conectiva, Inc." + \
+            "<p>Copyright &copy; " + copyright + \
             "<p><small>" + license + "</small>" + \
             "<p><h3>Credits</h3>" + "<br>".join(credits) + \
             "<p><a href=\""+website+"\">"+website+"</a>")
