@@ -3,6 +3,7 @@ import os
 from mocker import MockerTestCase
 
 from smart.backends.arch.base import ArchPackage, Package, Provides
+from smart.backends.arch.archver import splitarch, splitrelease
 from smart import sysconf
 
 
@@ -32,3 +33,15 @@ class ArchPackageTest(MockerTestCase):
         lst.sort()
         self.assertEquals(lst, [pkg1, pkg2, pkg3])
 
+class ArchVerSplitTest(MockerTestCase):
+
+    def test_splitarch(self):
+        version, arch = splitarch("1.0-1-i686")
+        self.assertEquals(version, "1.0-1")
+        self.assertEquals(arch, "i686")
+
+    def test_splitrelease(self):
+        version, release = splitrelease("1.0-1")
+        self.assertEquals(version, "1.0")
+        self.assertEquals(release, "1")
+
